import click
import json
from intellibot.api import IntelliBotAPI
from colorama import Fore, Style, init

init(autoreset=True)

intelli_bot = IntelliBotAPI()


@click.group()
def cli():
    pass


@cli.command()
@click.option("--username", prompt="Username", help="Username to connect")
@click.option(
    "--password",
    prompt=True,
    hide_input=True,
    confirmation_prompt=True,
    help="Password to connect",
)
def connect(username, password):
    """Connect to the intellibot."""
    response = intelli_bot.connect(username, password)
    if response.status_code == 200:
        click.echo(Fore.GREEN + "Connected successfully and credentials saved!")
    else:
        click.echo("Connection failed!")


@cli.command()
@click.argument("message", required=False)
def chat(message):
    """Chat with the intellibot."""
    click.echo(Fore.GREEN + "\t\t**** Welcome to intelligent chatbot!  ****\n\n")
    click.echo(Fore.GREEN + '\t\t**** Type "exit" to quit the chat. ****\n\n')

    if message:
        send_message(message)

    while True:
        message = click.prompt(Fore.BLUE + "You", type=str)
        if message.lower() in ["exit", "quit"]:
            click.echo(Fore.YELLOW + "\n\n \t\t\t***** Goodbye! *****\n\n")
            break
        send_message(message)


def send_message(message):
    try:
        response = intelli_bot.chat(message)
        if response.status_code == 200:
            click.echo(
                Fore.YELLOW
                + "\nintellibot: "
                + Style.RESET_ALL
                + f'{response.json().get("response")}\n'
            )
        else:
            click.echo(Fore.RED + "Failed to get a response from the bot.")
            click.echo(Fore.RED + f"Status Code: {response.status_code}")
            click.echo(Fore.RED + f"Response Content: {response.content}")
    except Exception as e:
        click.echo(str(e))


@cli.command()
@click.argument("config_file", type=click.Path(exists=True))
def initialize(config_file):
    """Initialize the AI agent system with a JSON configuration."""
    try:
        with open(config_file, 'r') as file:
            config_data = json.load(file)

        response = intelli_bot.initialize_crew(config_data)
        
        if response.status_code == 200:
            click.echo(Fore.GREEN + "AI agent system initialized successfully!")
        else:
            click.echo(Fore.RED + "Failed to initialize the AI agent system.")
            click.echo(Fore.RED + f"Status Code: {response.status_code}")
            click.echo(Fore.RED + f"Response Content: {response.content}")
    except Exception as e:
        click.echo(Fore.RED + str(e))


@cli.command()
def projects():
    """Check available projects."""
    try:
        response = intelli_bot.get_active_projects()
        if response.status_code == 200:
            projects = response.json().get("projects", [])
            click.echo(Fore.GREEN + "Available Projects:")
            for project in projects:
                click.echo(Fore.GREEN + f" - {project}")
        else:
            click.echo(Fore.RED + "Failed to retrieve projects.")
            click.echo(Fore.RED + f"Status Code: {response.status_code}")
            click.echo(Fore.RED + f"Response Content: {response.content}")
    except Exception as e:
        click.echo(Fore.RED + str(e))


@cli.command()
@click.argument("project_name")
def execute(project_name):
    """Execute a project."""
    try:
        response = intelli_bot.execute_project(project_name)
        if response.status_code == 200:
            result = response.json()
            click.echo(Fore.GREEN + f"Response: {result['response']}")
            click.echo(Fore.GREEN + f"Date Created: {result['date_created']}")
        else:
            click.echo(Fore.RED + "Failed to execute the project.")
            click.echo(Fore.RED + f"Status Code: {response.status_code}")
            click.echo(Fore.RED + f"Response Content: {response.content}")
    except Exception as e:
        click.echo(Fore.RED + str(e))


@cli.command()
def user_details():
    """View active user details."""
    try:
        response = intelli_bot.get_active_user_details()
        if response.status_code == 200:
            user_details = response.json()
            click.echo(Fore.GREEN + "Active User Details:\n")
            click.echo(Fore.GREEN + f" - User ID: {user_details.get('id')}")
            click.echo(Fore.GREEN + f" - User NAME: {user_details.get('name')}")
            click.echo(Fore.GREEN + f" - User EMAIL: {user_details.get('email')}")
        else:
            click.echo(Fore.RED + "Failed to retrieve active user details.")
            click.echo(Fore.RED + f"Status Code: {response.status_code}")
            click.echo(Fore.RED + f"Response Content: {response.content}")
    except Exception as e:
        click.echo(Fore.RED + str(e))


if __name__ == "__main__":
    cli()



import requests
import json
import os

BASE_URL = "https://intellihack-backend-rcbmvyttca-uc.a.run.app"
BASE_URL_LOCAL = "http://127.0.0.1:8000"
CREDENTIALS_FILE = "credentials.json"

class IntelliBotAPI:
    def __init__(self):
        self.access_token = None
        self.user_id = None
        self.username = None
        self.load_credentials()

    def load_credentials(self):
        if os.path.exists(CREDENTIALS_FILE):
            with open(CREDENTIALS_FILE, 'r') as file:
                credentials = json.load(file)
                self.access_token = credentials.get('access_token')
                self.user_id = credentials.get('user_id')
                self.username = credentials.get('username')

    def save_credentials(self, credentials):
        with open(CREDENTIALS_FILE, 'w') as file:
            json.dump(credentials, file)

    def connect(self, username, password):
        headers = {"Content-Type": "application/x-www-form-urlencoded"}
        data = {"username": username, "password": password}
        response = requests.post(BASE_URL + "/login", data=data, headers=headers)
        if response.status_code == 200:
            auth_data = response.json()
            self.access_token = auth_data["access_token"]
            self.user_id = auth_data["id"]
            self.username = auth_data["email"]
            self.save_credentials({
                "access_token": self.access_token,
                "user_id": self.user_id,
                "username": self.username,
            })
        return response

    def get_active_user_details(self):
        if not self.access_token or not self.user_id:
            raise Exception("User not authenticated. Please connect first.")

        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {self.access_token}",
        }
        response = requests.get(BASE_URL + f"/user/{self.user_id}", headers=headers)
        return response

    def chat(self, message, history=None):
        if not self.access_token or not self.user_id or not self.username:
            raise Exception("User not authenticated. Please connect first.")

        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {self.access_token}",
        }
        json_data = {
            "user_id": self.user_id,
            "username": self.username,
            "message": message,
            "history": history if history else "",
        }
        return requests.post(BASE_URL + "/query/chat", json=json_data, headers=headers)

    def initialize_crew(self, config_data):
        if not self.access_token or not self.user_id:
            raise Exception("User not authenticated. Please connect first.")

        config_data['user_id'] = self.user_id

        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {self.access_token}",
        }

        response = requests.post(
            BASE_URL_LOCAL + f"/agentConfiguration/",
            json=config_data,
            headers=headers,
        )
        return response

    def get_active_projects(self):
        if not self.access_token or not self.user_id:
            raise Exception("User not authenticated. Please connect first.")

        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {self.access_token}",
        }
        response = requests.get(
            f"{BASE_URL_LOCAL}/agentConfiguration/projects/{self.user_id}",
            headers=headers,
        )
        return response

    def execute_project(self, project_name):
        if not self.access_token:
            raise Exception("User not authenticated. Please connect first.")

        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {self.access_token}",
        }
        response = requests.get(
            f"{BASE_URL_LOCAL}/agentConfiguration/execute/{project_name}",
            headers=headers,
        )
        return response



from setuptools import setup, find_packages

setup(
    name='intellibot',
    version='0.2',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'click',
        'requests',
        'colorama',
    ],
    entry_points={
        'console_scripts': [
            'intellibot=intellibot.cli:cli',
        ],
    },
    author="Pawan Pinsara",
    author_email="1pawanpinsara@gmail.com",
    description="A CLI tool for interacting with intellibot API",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url="https://github.com/PinsaraPerera/intellihack_research_agent.git",
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
